@@ -33,6 +33,7 @@ except ImportError:
 from pymysql.cursors import Cursor
 
 from mycli.packages.special.main import Verbosity, parse_special_command
+from mycli.packages.sqlresult import SQLResult
 
 log = logging.getLogger(__name__)
 
@@ -225,11 +226,9 @@ def handle_llm(
 ) -> tuple[str, str | None, float]:
     _, verbosity, arg = parse_special_command(text)
     if not LLM_IMPORTED:
-        output = [(None, None, None, NEED_DEPENDENCIES)]
-        raise FinishIteration(output)
-    if not arg.strip():
-        output = [(None, None, None, USAGE)]
-        raise FinishIteration(output)
+        raise FinishIteration(results=[SQLResult(title=NEED_DEPENDENCIES, results=[])])
+    if arg.strip().lower() in ['', 'help', '?', r'\?']:
+        raise FinishIteration(results=[SQLResult(title=USAGE, results=[])])
     parts = shlex.split(arg)
     restart = False
     if "-c" in parts:
@@ -262,12 +261,11 @@ def handle_llm(
             if match:
                 sql = match.group(1).strip()
             else:
-                output = [(None, None, None, result)]
-                raise FinishIteration(output)
+                raise FinishIteration(results=[SQLResult(title=result, results=[])])
             return (result if verbosity == Verbosity.SUCCINCT else "", sql, end - start)
         else:
             run_external_cmd("llm", *args, restart_cli=restart)
-            raise FinishIteration(None)
+            raise FinishIteration(results=None)
     try:
         ensure_mycli_template()
         start = time()
@@ -392,8 +390,6 @@ def sql_using_llm(
         question,
         " ",
     ]
-    click.echo(args[4])
-    click.echo(args[7])
     click.echo("Invoking llm command with schema information and sample data")
     _, result = run_external_cmd("llm", *args, capture_output=True)
     click.echo("Received response from the llm command")
