@@ -2,7 +2,12 @@
 
 import pytest
 
-from mycli.packages.completion_engine import suggest_type
+from mycli.packages import special
+from mycli.packages.completion_engine import (
+    _find_doubled_backticks,
+    is_inside_quotes,
+    suggest_type,
+)
 
 
 def sorted_dicts(dicts):
@@ -538,6 +543,13 @@ def test_specials_included_for_initial_completion(initial_text):
     assert sorted_dicts(suggestions) == sorted_dicts([{"type": "keyword"}, {"type": "special"}])
 
 
+@pytest.mark.parametrize('initial_text', ['REDIRECT'])
+def test_specials_included_with_caps(initial_text):
+    suggestions = suggest_type(initial_text, initial_text)
+
+    assert sorted_dicts(suggestions) == sorted_dicts([{'type': 'keyword'}, {'type': 'special'}])
+
+
 def test_specials_not_included_after_initial_token():
     suggestions = suggest_type("create table foo (dt d", "create table foo (dt d")
 
@@ -593,6 +605,8 @@ def test_after_as(expression):
     ],
 )
 def test_source_is_file(expression):
+    # "source" has to be registered by hand because that usually happens inside MyCLI in mycli/main.py
+    special.register_special_command(..., 'source', '\\. <filename>', 'Execute commands from file.', aliases=['\\.'])
     suggestions = suggest_type(expression, expression)
     assert suggestions == [{"type": "file_name"}]
 
@@ -618,3 +632,81 @@ def test_quoted_where():
     text = "'where i=';"
     suggestions = suggest_type(text, text)
     assert suggestions == [{"type": "keyword"}]
+
+
+def test_find_doubled_backticks_none():
+    text = 'select `ab`'
+    assert _find_doubled_backticks(text) == []
+
+
+def test_find_doubled_backticks_some():
+    text = 'select `a``b`'
+    assert _find_doubled_backticks(text) == [9, 10]
+
+
+def test_inside_quotes_01():
+    text = "select '"
+    assert is_inside_quotes(text, len(text)) == 'single'
+
+
+def test_inside_quotes_02():
+    text = "select '\\'"
+    assert is_inside_quotes(text, len(text)) == 'single'
+
+
+def test_inside_quotes_03():
+    text = "select '`"
+    assert is_inside_quotes(text, len(text)) == 'single'
+
+
+def test_inside_quotes_04():
+    text = 'select "'
+    assert is_inside_quotes(text, len(text)) == 'double'
+
+
+def test_inside_quotes_05():
+    text = 'select "\\"\''
+    assert is_inside_quotes(text, len(text)) == 'double'
+
+
+def test_inside_quotes_06():
+    text = 'select ""'
+    assert is_inside_quotes(text, len(text)) is False
+
+
+@pytest.mark.parametrize(
+    ["text", "position", "expected"],
+    [
+        ("select `'",      len("select `'"),  'backtick'),
+        ("select `' ",     len("select `' "), 'backtick'),
+        ("select `'",      -1,  'backtick'),
+        ("select `'",      -2,  False),
+        ('select `ab` ',   -1,  False),
+        ('select `ab` ',   -2,  'backtick'),
+        ('select `a``b` ', -1,  False),
+        ('select `a``b` ', -2,  'backtick'),
+        ('select `a``b` ', -3,  'backtick'),
+        ('select `a``b` ', -4,  'backtick'),
+        ('select `a``b` ', -5,  'backtick'),
+        ('select `a``b` ', -6,  'backtick'),
+        ('select `a``b` ', -7,  False),
+    ]
+)  # fmt: skip
+def test_inside_quotes_backtick_01(text, position, expected):
+    assert is_inside_quotes(text, position) == expected
+
+
+def test_inside_quotes_backtick_02():
+    """Empty backtick pairs are treated as a doubled (escaped) backtick.
+    This is okay because it is invalid SQL, and we don't have to complete on it.
+    """
+    text = 'select ``'
+    assert is_inside_quotes(text, -1) is False
+
+
+def test_inside_quotes_backtick_03():
+    """Empty backtick pairs are treated as a doubled (escaped) backtick.
+    This is okay because it is invalid SQL, and we don't have to complete on it.
+    """
+    text = 'select ``'
+    assert is_inside_quotes(text, -2) is False
